@@ -53,8 +53,8 @@ class DebugReportTest : public ::testing::Test {
         env = std::unique_ptr<FrameworkEnvironment>(new FrameworkEnvironment());
         for (uint32_t icd = 0; icd < 3; ++icd) {
             env->add_icd(TestICDDetails(TEST_ICD_PATH_VERSION_2_EXPORT_ICD_GPDPA, VK_API_VERSION_1_0));
-            env->get_test_icd(icd).physical_devices.push_back({});
-            env->get_test_icd(icd).physical_devices.push_back({});
+            env->get_test_icd(icd).add_physical_device({});
+            env->get_test_icd(icd).add_physical_device({});
         }
         // Initialize the expected output
         allow_any_message = false;
@@ -387,8 +387,8 @@ class DebugUtilTest : public ::testing::Test {
         env = std::unique_ptr<FrameworkEnvironment>(new FrameworkEnvironment());
         for (uint32_t icd = 0; icd < 3; ++icd) {
             env->add_icd(TestICDDetails(TEST_ICD_PATH_VERSION_2_EXPORT_ICD_GPDPA, VK_API_VERSION_1_0));
-            env->get_test_icd(icd).physical_devices.push_back({});
-            env->get_test_icd(icd).physical_devices.push_back({});
+            env->get_test_icd(icd).add_physical_device({});
+            env->get_test_icd(icd).add_physical_device({});
         }
         // Initialize the expected output
         allow_any_message = false;
@@ -1041,9 +1041,8 @@ void CheckDeviceFunctions(FrameworkEnvironment& env, bool use_GIPA, bool enable_
 
 TEST(GetProcAddr, DebugFuncsWithTerminator) {
     FrameworkEnvironment env{};
-    auto& driver =
-        env.add_icd(TestICDDetails(TEST_ICD_PATH_VERSION_2_EXPORT_ICD_GPDPA)).setup_WSI().add_physical_device("physical_device_0");
-    driver.physical_devices.at(0).add_extensions({"VK_KHR_swapchain"});
+    auto& driver = env.add_icd(TestICDDetails(TEST_ICD_PATH_VERSION_2_EXPORT_ICD_GPDPA)).setup_WSI();
+    auto& phys_dev = driver.add_and_get_physical_device("physical_device_0").add_extensions({"VK_KHR_swapchain"});
     // Hardware doesn't support the debug extensions
 
     // Use getDeviceProcAddr & vary enabling the debug extensions
@@ -1056,7 +1055,7 @@ TEST(GetProcAddr, DebugFuncsWithTerminator) {
 
     // Now set the hardware to support the extensions and run the situations again
     driver.add_instance_extensions({"VK_EXT_debug_utils", "VK_EXT_debug_report"});
-    driver.physical_devices.at(0).add_extensions({"VK_EXT_debug_marker"});
+    phys_dev.add_extensions({"VK_EXT_debug_marker"});
 
     // Use getDeviceProcAddr & vary enabling the debug extensions
     ASSERT_NO_FATAL_FAILURE(CheckDeviceFunctions(env, false, false, true));
@@ -1069,9 +1068,10 @@ TEST(GetProcAddr, DebugFuncsWithTerminator) {
 
 TEST(GetProcAddr, DebugFuncsWithTrampoline) {
     FrameworkEnvironment env{};
-    auto& driver =
-        env.add_icd(TestICDDetails(TEST_ICD_PATH_VERSION_2_EXPORT_ICD_GPDPA)).setup_WSI().add_physical_device("physical_device_0");
-    driver.physical_devices.at(0).add_extensions({"VK_KHR_swapchain"});
+    auto& driver = env.add_icd(TestICDDetails(TEST_ICD_PATH_VERSION_2_EXPORT_ICD_GPDPA))
+                       .setup_WSI()
+                       .add_and_get_physical_device("physical_device_0")
+                       .add_extensions({"VK_KHR_swapchain"});
     // Hardware doesn't support the debug extensions
 
     // Use getDeviceProcAddr & vary enabling the debug extensions
@@ -1103,9 +1103,10 @@ TEST(GetProcAddr, DebugFuncsWithTrampoline) {
 
 TEST(GetProcAddr, DebugFuncsWithDebugExtsForceAdded) {
     FrameworkEnvironment env{};
-    auto& driver =
-        env.add_icd(TestICDDetails(TEST_ICD_PATH_VERSION_2_EXPORT_ICD_GPDPA)).setup_WSI().add_physical_device("physical_device_0");
-    driver.physical_devices.at(0).add_extensions({"VK_KHR_swapchain"});
+    auto& driver = env.add_icd(TestICDDetails(TEST_ICD_PATH_VERSION_2_EXPORT_ICD_GPDPA))
+                       .setup_WSI()
+                       .add_and_get_physical_device("physical_device_0")
+                       .add_extensions({"VK_KHR_swapchain"});
     // Hardware doesn't support the debug extensions
 
     // Use getDeviceProcAddr & vary enabling the debug extensions
